import http from 'http';
import httpProxy from 'http-proxy';
import { useConfig } from '@abearxiong/use-config';

const { resources, api } = useConfig<{
  resources: string;
  api: { host: string };
}>();
const proxy = httpProxy.createProxyServer({});
const fetchTest = async (id: string) => {
  const fetchUrl = 'http://' + api.host + '/api/router';
  const fetchRes = await fetch(fetchUrl, {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json',
    },
    body: JSON.stringify({
      path: 'user-app',
      key: 'test',
      id: id,
    }),
  }).then((res) => res.json());
  return fetchRes;
};
// 60939f5e-f51b-4563-8c96-7a98ac5ac259
export const handleProxyRequest = async (req: http.IncomingMessage, res: http.ServerResponse) => {
  const url = req.url;
  const urls = url.split('/');
  const [_, test, id] = urls;
  const error = (msg: string) => {
    res.writeHead(404, { 'Content-Type': 'text/plain' });
    res.write(msg);
    res.end();
  };
  if (test !== 'test') {
    error('Not Found');
    return;
  }
  if (!id) {
    error('Need Test ID');
    return;
  }
  // 判断id是uuid
  if (!isUUID(id)) {
    error('Need Test ID is UUID');
    return;
  }
  const result = await fetchTest(id);
  console.log('data', result);
  if (result.code !== 200) {
    error('fetch error');
    return;
  }
  const files = result.data?.data?.files;
  const appFileUrl = (url + '').replace(`/${test}/${id}/`, '');
  const pathFile = files.find((file: any) => file.name === appFileUrl);
  const target = `https://${resources}/${pathFile.path}`;
  console.log('target', target);
  proxy.web(req, res, { target: target, secure: false });
};
function isUUID(id: string): boolean {
  const uuidRegex = /^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$/i;
  return uuidRegex.test(id);
}
